@@ -11,7 +11,6 @@ import warnings
 import json
 
 from lxml import etree
-import six
 from webob import Response
 
 from xblock.exceptions import JsonHandlerError, KeyValueMultiSaveError, XBlockSaveError, FieldDataDeprecationWarning
@@ -117,7 +116,7 @@ class RuntimeServicesMixin:
                 It is available in XBlock code as ``self.runtime``.
         """
         self.runtime = runtime
-        super(RuntimeServicesMixin, self).__init__(**kwargs)
+        super().__init__(**kwargs)
 
     @classmethod
     def needs(cls, *service_names):
@@ -156,7 +155,7 @@ class RuntimeServicesMixin:
 
 
 @RuntimeServicesMixin.needs('field-data')
-class ScopedStorageMixin(six.with_metaclass(NamedAttributesMetaclass, RuntimeServicesMixin)):
+class ScopedStorageMixin(RuntimeServicesMixin, metaclass=NamedAttributesMetaclass):
     """
     This mixin provides scope for Fields and the associated Scoped storage.
     """
@@ -217,7 +216,7 @@ class ScopedStorageMixin(six.with_metaclass(NamedAttributesMetaclass, RuntimeSer
         self._dirty_fields = {}
         self.scope_ids = scope_ids
 
-        super(ScopedStorageMixin, self).__init__(**kwargs)
+        super().__init__(**kwargs)
 
     @property
     def _field_data(self):
@@ -272,8 +271,8 @@ class ScopedStorageMixin(six.with_metaclass(NamedAttributesMetaclass, RuntimeSer
                 fields.remove(field)
                 # if the field was dirty, delete from dirty fields
                 self._reset_dirty_field(field)
-            msg = 'Error saving fields {}'.format(save_error.saved_field_names)
-            raise XBlockSaveError(saved_fields, fields, msg)
+            msg = f'Error saving fields {save_error.saved_field_names}'
+            raise XBlockSaveError(saved_fields, fields, msg)  # pylint: disable= raise-missing-from
 
         # Remove all dirty fields, since the save was successful
         for field in fields:
@@ -308,21 +307,21 @@ class ScopedStorageMixin(six.with_metaclass(NamedAttributesMetaclass, RuntimeSer
         # Since this is not understood by static analysis, silence this error.
         # pylint: disable=E1101
         attrs = []
-        for field in six.itervalues(self.fields):
+        for field in self.fields.values():
             try:
                 value = getattr(self, field.name)
             except Exception:  # pylint: disable=broad-except
                 # Ensure we return a string, even if unanticipated exceptions.
-                attrs.append(" %s=???" % (field.name,))
+                attrs.append(" {}=???".format(field.name))
             else:
-                if isinstance(value, six.binary_type):
+                if isinstance(value, bytes):
                     value = value.decode('utf-8', errors='escape')
-                if isinstance(value, six.text_type):
+                if isinstance(value, str):
                     value = value.strip()
                     if len(value) > 40:
                         value = value[:37] + "..."
-                attrs.append(" %s=%r" % (field.name, value))
-        return "<%s @%04X%s>" % (
+                attrs.append(" {}={!r}".format(field.name, value))
+        return "<{} @{:04X}{}>".format(
             self.__class__.__name__,
             id(self) % 0xFFFF,
             ','.join(attrs)
@@ -343,10 +342,10 @@ class ChildrenModelMetaclass(ScopedStorageMixin.__class__):
         else:
             attrs['has_children'] = False
 
-        return super(ChildrenModelMetaclass, mcs).__new__(mcs, name, bases, attrs)
+        return super().__new__(mcs, name, bases, attrs)
 
 
-class HierarchyMixin(six.with_metaclass(ChildrenModelMetaclass, ScopedStorageMixin)):
+class HierarchyMixin(ScopedStorageMixin, metaclass=ChildrenModelMetaclass):
     """
     This adds Fields for parents and children.
     """
@@ -365,7 +364,7 @@ class HierarchyMixin(six.with_metaclass(ChildrenModelMetaclass, ScopedStorageMix
             self._parent_block = for_parent
             self._parent_block_id = for_parent.scope_ids.usage_id
 
-        super(HierarchyMixin, self).__init__(**kwargs)
+        super().__init__(**kwargs)
 
     def get_parent(self):
         """Return the parent block of this block, or None if there isn't one."""
