@@ -25,8 +25,7 @@ particular combination of initial conditions that we want to test)
 """
 import copy
 
-from mock import Mock, patch
-import six
+from unittest.mock import Mock, patch
 
 from xblock.core import XBlock
 from xblock.fields import Integer, List, String, ScopeIds, UNIQUE_ID
@@ -403,7 +402,7 @@ class UniversalTestCases(UniversalProperties):
 class DictFieldDataWithSequentialDefault(DictFieldData):
     """:class:`~xblock.test.tools.DictFieldData` that generates a sequence of default values"""
     def __init__(self, storage, sequence):
-        super(DictFieldDataWithSequentialDefault, self).__init__(storage)
+        super().__init__(storage)
         self._sequence = sequence
 
     def default(self, block, name):
@@ -464,7 +463,7 @@ class TestImmutableWithComputedDefault(ImmutableTestCases, ComputedDefaultTestCa
 
     @property
     def default_iterator(self):
-        return six.moves.range(1000)
+        return range(1000)
 
 
 class TestMutableWithStaticDefault(MutableTestCases, StaticDefaultTestCases, DefaultValueMutationProperties):
@@ -481,7 +480,7 @@ class TestMutableWithComputedDefault(MutableTestCases, ComputedDefaultTestCases,
 
     @property
     def default_iterator(self):
-        return ([None] * i for i in six.moves.range(1000))
+        return ([None] * i for i in range(1000))
 
 
 class TestImmutableWithInitialValue(ImmutableTestCases, InitialValueProperties):
@@ -509,7 +508,7 @@ class GetNoopPrefix:
         self.block  # An initialized xblock with a field named `field`
     """
     def setup_method(self):
-        super(GetNoopPrefix, self).setup_method()
+        super().setup_method()
         self.get()
 
 
@@ -523,7 +522,7 @@ class GetSaveNoopPrefix:
         self.block  # An initialized xblock with a field named `field`
     """
     def setup_method(self):
-        super(GetSaveNoopPrefix, self).setup_method()
+        super().setup_method()
         self.get()
         self.block.save()
 
@@ -538,7 +537,7 @@ class SaveNoopPrefix:
         self.block  # An initialized xblock with a field named `field`
     """
     def setup_method(self):
-        super(SaveNoopPrefix, self).setup_method()
+        super().setup_method()
         self.block.save()
 # pylint: enable=no-member
 
