@@ -3,7 +3,6 @@ Tests for the UserService
 """
 import collections
 import pytest
-import six
 
 from xblock.reference.user_service import XBlockUser, UserService
 
@@ -13,7 +12,7 @@ class SingleUserService(UserService):
     This is a dummy user service for testing that always returns a single user.
     """
     def __init__(self, user):
-        super(SingleUserService, self).__init__()
+        super().__init__()
         self.user = user
 
     def get_current_user(self):
@@ -31,7 +30,7 @@ def test_dummy_user_service_current_user():
     assert current_user.full_name == "tester"
     # assert that emails is an Iterable but not a string
     assert isinstance(current_user.emails, collections.Iterable)
-    assert not isinstance(current_user.emails, (six.text_type, six.binary_type))
+    assert not isinstance(current_user.emails, (str, bytes))
     # assert that opt_attrs is a Mapping
     assert isinstance(current_user.opt_attrs, collections.Mapping)
 
